@@ -1,7 +1,7 @@
 use assert_cmd::Command;
 
 #[test]
-fn version() {
+fn flag_version() {
     let mut clc = bin();
     clc.arg("--version");
     clc.assert()
@@ -9,6 +9,15 @@ fn version() {
         .stdout(format!("clc {}\n", env!("CARGO_PKG_VERSION")));
 }
 
+#[test]
+fn flag_eval() {
+    for flag in ["--eval", "-e"] {
+        let mut clc = bin();
+        clc.args([flag, "sqrt(100)"]);
+        clc.assert().success().stdout("10\n");
+    }
+}
+
 // NOTE: IMPROVEMENT
 // Currently we have no idea to test eval loop :(
 
